@@ -26,10 +26,6 @@ from sushy import utils
 LOG = logging.getLogger(__name__)
 
 
-_SERVER_SIDE_RETRIES = 5
-_SERVER_SIDE_RETRY_DELAY = 3
-
-
 class Connector(object):
 
     def __init__(
@@ -40,11 +36,7 @@ class Connector(object):
         self._session = requests.Session()
         self._session.verify = self._verify
         self._response_callback = response_callback
-        self._auth = None
 
-        # NOTE(TheJulia): In order to help prevent recursive post operations
-        # by allowing us to understand that we should stop authentication.
-        self._sessions_uri = None
         # NOTE(etingof): field studies reveal that some BMCs choke at
         # long-running persistent HTTP connections (or TCP connections).
         # By default, we ask HTTP server to shut down HTTP connection we've
@@ -76,8 +68,7 @@ class Connector(object):
         self._session.close()
 
     def _op(self, method, path='', data=None, headers=None, blocking=False,
-            timeout=60, server_side_retries=_SERVER_SIDE_RETRIES,
-            **extra_session_req_kwargs):
+            timeout=60, **extra_session_req_kwargs):
         """Generic RESTful request handler.
 
         :param method: The HTTP method to be used, e.g: GET, POST,
@@ -97,10 +88,7 @@ class Connector(object):
         url = path if urlparse.urlparse(path).netloc else urlparse.urljoin(
             self._url, path)
         headers = headers or {}
-        lc_headers = [k.lower() for k in headers]
-        if data is not None and 'content-type' not in lc_headers:
-            headers['Content-Type'] = 'application/json'
-        if 'odata-version' not in lc_headers:
+        if not any(k.lower() == 'odata-version' for k in headers):
             headers['OData-Version'] = '4.0'
         # TODO(lucasagomes): We should mask the data to remove sensitive
         # information
@@ -129,23 +117,9 @@ class Connector(object):
         try:
             exceptions.raise_for_response(method, url, response)
         except exceptions.AccessError as e:
-            if (method == 'POST'
-                    and self._sessions_uri is not None
-                    and self._sessions_uri in url):
-                LOG.error('Authentication to the session service failed. '
-                          'Please check credentials and try again.')
-                raise
-            if self._auth is not None:
+            if self._auth.can_refresh_session():
                 try:
-                    if self._auth.can_refresh_session():
-                        self._auth.refresh_session()
-                    else:
-                        LOG.warning('Session authentication appears to have '
-                                    'been lost at some point in time. '
-                                    'Connectivity may have been lost during '
-                                    'a prior session refresh. Attempting to '
-                                    're-authenticate.')
-                        self._auth.authenticate()
+                    self._auth.refresh_session()
                 except exceptions.AccessError as refresh_exc:
                     LOG.error("A failure occured while attempting to refresh "
                               "the session. Error: %s", refresh_exc.message)
@@ -163,26 +137,9 @@ class Connector(object):
                               "%s", retry_exc.message)
                     raise
             else:
-                if method == 'GET' and url.endswith('SessionService'):
-                    LOG.debug('HTTP GET of SessionService failed %s, '
-                              'this is expected prior to authentication',
-                              e.message)
-                else:
-                    LOG.error("Authentication error detected. Cannot proceed: "
-                              "%s", e.message)
+                LOG.error("Authentication error detected. Cannot proceed: "
+                          "%s", e.message)
                 raise
-        except exceptions.ServerSideError as e:
-            if method.lower() != 'get' or server_side_retries <= 0:
-                raise
-            else:
-                LOG.warning('Got server side error %s in response to a '
-                            'GET request, retrying after %d seconds',
-                            e, _SERVER_SIDE_RETRY_DELAY)
-                time.sleep(_SERVER_SIDE_RETRY_DELAY)
-                return self._op(method, path, data=data, headers=headers,
-                                blocking=blocking, timeout=timeout,
-                                server_side_retries=server_side_retries - 1,
-                                **extra_session_req_kwargs)
 
         if blocking and response.status_code == 202:
             if not response.headers.get('location'):
