@@ -27,8 +27,8 @@ from sushy.resources.oem import fake
 from sushy.resources.system import bios
 from sushy.resources.system import mappings as sys_map
 from sushy.resources.system import processor
+from sushy.resources.system import secure_boot
 from sushy.resources.system import simple_storage
-from sushy.resources.system.storage import storage
 from sushy.resources.system import system
 from sushy.tests.unit import base
 
@@ -51,7 +51,7 @@ class SystemTestCase(base.TestCase):
         self.sys_inst._parse_attributes(self.json_doc)
         self.assertEqual('1.0.2', self.sys_inst.redfish_version)
         self.assertEqual('Chicago-45Z-2381', self.sys_inst.asset_tag)
-        self.assertEqual('P79 v1.33 (02/28/2015)', self.sys_inst.bios_version)
+        self.assertEqual('P79 v1.45 (12/06/2017)', self.sys_inst.bios_version)
         self.assertEqual('Web Front End node', self.sys_inst.description)
         self.assertEqual('web483', self.sys_inst.hostname)
         self.assertEqual('437XR1138R2', self.sys_inst.identity)
@@ -83,6 +83,42 @@ class SystemTestCase(base.TestCase):
         for oem_vendor in self.sys_inst.oem_vendors:
             self.assertIn(oem_vendor, ('Contoso', 'Chipwise'))
 
+    def test__parse_attributes_return(self):
+        attributes = self.sys_inst._parse_attributes(self.json_doc)
+
+        # Test that various types are returned correctly
+        self.assertEqual('Chicago-45Z-2381', attributes.get('asset_tag'))
+        self.assertEqual(sushy.INDICATOR_LED_OFF,
+                         attributes.get('indicator_led'))
+        self.assertEqual({'health': res_cons.HEALTH_OK,
+                          'health_rollup': res_cons.HEALTH_OK,
+                          'state': res_cons.STATE_ENABLED},
+                         attributes.get('status'))
+        self.assertEqual({'maintenance_window_duration_in_seconds': 1,
+                          'maintenance_window_start_time':
+                          parser.parse('2016-03-07T14:44:30-05:05')},
+                         attributes.get('maintenance_window'))
+        self.assertEqual({'reset': {'allowed_values':
+                         ['On', 'ForceOff', 'GracefulShutdown',
+                             'GracefulRestart', 'ForceRestart', 'Nmi',
+                             'ForceOn', 'PushPowerButton'],
+                         'operation_apply_time_support':
+                         {'_maintenance_window_resource':
+                             {'resource_uri':
+                                 '/redfish/v1/Systems/437XR1138R2'},
+                          'maintenance_window_duration_in_seconds': 600,
+                          'maintenance_window_start_time':
+                              parser.parse('2017-05-03T23:12:37-05:00'),
+                          'supported_values':
+                              ['Immediate', 'AtMaintenanceWindowStart'],
+                          'mapped_supported_values':
+                              [res_cons.APPLY_TIME_IMMEDIATE,
+                               res_cons.APPLY_TIME_MAINT_START]},
+                         'target_uri':
+                         '/redfish/v1/Systems/437XR1138R2/Actions/'
+                         'ComputerSystem.Reset'}},
+                         attributes.get('_actions'))
+
     def test__parse_attributes_missing_actions(self):
         self.sys_inst.json.pop('Actions')
         self.assertRaisesRegex(
@@ -127,7 +163,8 @@ class SystemTestCase(base.TestCase):
                           "GracefulRestart",
                           "ForceRestart",
                           "Nmi",
-                          "ForceOn"
+                          "ForceOn",
+                          "PushPowerButton"
                           ],
                          value.allowed_values)
 
@@ -145,7 +182,8 @@ class SystemTestCase(base.TestCase):
                         sushy.RESET_FORCE_OFF,
                         sushy.RESET_FORCE_ON,
                         sushy.RESET_ON,
-                        sushy.RESET_NMI])
+                        sushy.RESET_NMI,
+                        sushy.RESET_PUSH_POWER_BUTTON])
         self.assertEqual(expected, values)
         self.assertIsInstance(values, set)
 
@@ -172,6 +210,9 @@ class SystemTestCase(base.TestCase):
         self.assertIsNotNone(support)
         self.assertEqual(['Immediate', 'AtMaintenanceWindowStart'],
                          support.supported_values)
+        self.assertEqual([res_cons.APPLY_TIME_IMMEDIATE,
+                          res_cons.APPLY_TIME_MAINT_START],
+                         support.mapped_supported_values)
         self.assertEqual(parser.parse('2017-05-03T23:12:37-05:00'),
                          support.maintenance_window_start_time)
         self.assertEqual(600, support.maintenance_window_duration_in_seconds)
@@ -486,6 +527,15 @@ class SystemTestCase(base.TestCase):
         self.assertEqual('BIOS Configuration Current Settings',
                          self.sys_inst.bios.name)
 
+    def test_secure_boot(self):
+        self.conn.get.return_value.json.reset_mock()
+        with open('sushy/tests/unit/json_samples/secure_boot.json') as f:
+            self.conn.get.return_value.json.side_effect = [json.load(f)]
+
+        self.assertIsInstance(self.sys_inst.secure_boot,
+                              secure_boot.SecureBoot)
+        self.assertEqual('UEFI Secure Boot', self.sys_inst.secure_boot.name)
+
     def test_simple_storage_for_missing_attr(self):
         self.sys_inst.json.pop('SimpleStorage')
         with self.assertRaisesRegex(
@@ -538,7 +588,7 @@ class SystemTestCase(base.TestCase):
                               simple_storage.SimpleStorageCollection)
 
     def test_storage_for_missing_attr(self):
-        self.sys_inst.json.pop('Storage')
+        self.sys_inst.json.pop('SimpleStorage')
         with self.assertRaisesRegex(
                 exceptions.MissingAttributeError, 'attribute Storage'):
             self.sys_inst.storage
@@ -550,16 +600,17 @@ class SystemTestCase(base.TestCase):
                   'storage_collection.json') as f:
             self.conn.get.return_value.json.return_value = json.load(f)
         # | WHEN |
-        actual_storage = self.sys_inst.storage
+        actual_storage = self.sys_inst.simple_storage
         # | THEN |
-        self.assertIsInstance(actual_storage, storage.StorageCollection)
+        self.assertIsInstance(actual_storage,
+                              simple_storage.SimpleStorageCollection)
         self.conn.get.return_value.json.assert_called_once_with()
 
         # reset mock
         self.conn.get.return_value.json.reset_mock()
         # | WHEN & THEN |
         # tests for same object on invoking subsequently
-        self.assertIs(actual_storage, self.sys_inst.storage)
+        self.assertIs(actual_storage, self.sys_inst.simple_storage)
         self.conn.get.return_value.json.assert_not_called()
 
     def test_storage_on_refresh(self):
@@ -568,8 +619,8 @@ class SystemTestCase(base.TestCase):
                   'storage_collection.json') as f:
             self.conn.get.return_value.json.return_value = json.load(f)
         # | WHEN & THEN |
-        self.assertIsInstance(self.sys_inst.storage,
-                              storage.StorageCollection)
+        self.assertIsInstance(self.sys_inst.simple_storage,
+                              simple_storage.SimpleStorageCollection)
 
         # On refreshing the system instance...
         with open('sushy/tests/unit/json_samples/system.json') as f:
@@ -583,7 +634,8 @@ class SystemTestCase(base.TestCase):
                   'storage_collection.json') as f:
             self.conn.get.return_value.json.return_value = json.load(f)
         # | WHEN & THEN |
-        self.assertIsInstance(self.sys_inst.storage, storage.StorageCollection)
+        self.assertIsInstance(self.sys_inst.simple_storage,
+                              simple_storage.SimpleStorageCollection)
 
     def test_managers(self):
         # | GIVEN |
