@@ -220,7 +220,6 @@ class ConnectorOpTestCase(base.TestCase):
         self.conn._session.headers['X-Auth-Token'] = 'asdf1234'
         expected_headers = self.headers.copy()
         expected_headers['OData-Version'] = '4.0'
-        expected_headers['Content-Type'] = 'application/json'
         self.conn._op('POST', path='fake/path', headers=self.headers,
                       data=self.data)
         self.request.assert_called_once_with(
@@ -263,11 +262,6 @@ class ConnectorOpTestCase(base.TestCase):
         self.request = self.session.request
         self.request.return_value.status_code = http_client.FORBIDDEN
         self.request.return_value.json.side_effect = ValueError('no json')
-        mock_response = mock.Mock()
-        mock_response.json.side_effect = ValueError('no json')
-        mock_response.status_code = http_client.FORBIDDEN
-        self.conn._auth.authenticate.side_effect = \
-            exceptions.AccessError('POST', 'fake/path', mock_response)
         with self.assertRaisesRegex(exceptions.AccessError,
                                     'unknown error') as ae:
             self.conn._op('POST', path='fake/path', data=self.data,
@@ -294,42 +288,6 @@ class ConnectorOpTestCase(base.TestCase):
         self.auth.can_refresh_session.assert_called_with()
         self.assertEqual(response.json, second_response.json)
 
-    def test_timed_out_session_timed_out_refresh(self):
-        self.auth._session_key = 'asdf1234'
-        self.auth.get_session_key.return_value = 'asdf1234'
-        self.conn._auth = self.auth
-        self.session = mock.Mock(spec=requests.Session)
-        self.conn._session = self.session
-        self.request = self.session.request
-        first_response = mock.MagicMock()
-        first_response.status_code = http_client.FORBIDDEN
-        second_response = first_response
-        self.auth.refresh_session.side_effect = \
-            exceptions.ConnectionError()
-        third_response = mock.MagicMock()
-        third_response.status_code = http_client.OK
-        third_response.json = {'Test': 'Testing'}
-        self.auth.can_refresh_session.return_value = True
-
-        self.request.side_effect = [first_response, second_response,
-                                    third_response]
-        self.assertRaises(exceptions.ConnectionError, self.conn._op, 'POST',
-                          path='fake/path', data=self.data,
-                          headers=self.headers)
-        self.auth.refresh_session.assert_called_with()
-        self.auth.refresh_session.reset_mock()
-        # Normally, this would be reset by refresh_session, but given
-        # the heavy mocking, we need to do it for this test.
-        self.auth._session_key = None
-        self.auth.get_session_key.return_value = None
-        self.auth.can_refresh_session.return_value = False
-
-        response = self.conn._op('POST', path='fake/path', data=self.data,
-                                 headers=self.headers)
-        self.auth.refresh_session.assert_not_called()
-        self.auth.authenticate.assert_called_once()
-        self.assertEqual(response.json, third_response.json)
-
     def test_connection_error(self):
         self.request.side_effect = requests.exceptions.ConnectionError
         self.assertRaises(exceptions.ConnectionError, self.conn._op, 'GET')
@@ -359,23 +317,7 @@ class ConnectorOpTestCase(base.TestCase):
         self.assertIsNotNone(exc.body)
         self.assertIn('body submitted was malformed JSON', exc.detail)
 
-    def test_known_http_error_nonlist_ext_info(self):
-        self.request.return_value.status_code =\
-            http_client.UNSUPPORTED_MEDIA_TYPE
-        with open('sushy/tests/unit/json_samples/'
-                  'error_single_ext_info.json') as f:
-            self.request.return_value.json.return_value = json.load(f)
-
-        with self.assertRaisesRegex(exceptions.HTTPError,
-                                    'See Resolution for information') as cm:
-            self.conn._op('POST', 'http://foo.bar')
-        exc = cm.exception
-        self.assertEqual(http_client.UNSUPPORTED_MEDIA_TYPE, exc.status_code)
-        self.assertIsNotNone(exc.body)
-        self.assertIn('See Resolution for information', exc.detail)
-
-    @mock.patch('time.sleep', autospec=True)
-    def test_not_found_error(self, mock_sleep):
+    def test_not_found_error(self):
         self.request.return_value.status_code = http_client.NOT_FOUND
         self.request.return_value.json.side_effect = ValueError('no json')
 
@@ -384,11 +326,8 @@ class ConnectorOpTestCase(base.TestCase):
             self.conn._op('GET', 'http://foo.bar')
         exc = cm.exception
         self.assertEqual(http_client.NOT_FOUND, exc.status_code)
-        self.assertFalse(mock_sleep.called)
-        self.assertEqual(1, self.request.call_count)
 
-    @mock.patch('time.sleep', autospec=True)
-    def test_server_error(self, mock_sleep):
+    def test_server_error(self):
         self.request.return_value.status_code = (
             http_client.INTERNAL_SERVER_ERROR)
         self.request.return_value.json.side_effect = ValueError('no json')
@@ -398,105 +337,18 @@ class ConnectorOpTestCase(base.TestCase):
             self.conn._op('GET', 'http://foo.bar')
         exc = cm.exception
         self.assertEqual(http_client.INTERNAL_SERVER_ERROR, exc.status_code)
-        self.assertEqual(5, mock_sleep.call_count)
-        self.assertEqual(6, self.request.call_count)
 
     def test_access_error(self):
-        self.conn._auth = None
-
-        self.request.return_value.status_code = http_client.FORBIDDEN
-        self.request.return_value.json.side_effect = ValueError('no json')
-
-        with self.assertRaisesRegex(exceptions.AccessError,
-                                    'unknown error') as cm:
-            self.conn._op('GET', 'http://foo.bar')
-        exc = cm.exception
-        self.assertEqual(http_client.FORBIDDEN, exc.status_code)
-
-    def test_access_error_on_session_post_does_not_retry(self):
-        self.request.return_value.status_code = http_client.FORBIDDEN
-        self.request.return_value.json.side_effect = ValueError('no json')
-
-        self.conn._sessions_uri = '/redfish/v1/SessionService/Sessions'
-
-        with self.assertRaisesRegex(exceptions.AccessError,
-                                    'unknown error') as cm:
-            self.conn._op('POST', 'http://foo.bar/redfish/v1/Session'
-                                  'Service/Sessions',
-                          data={'foo': 'bar'})
-        exc = cm.exception
-        self.assertEqual(http_client.FORBIDDEN, exc.status_code)
-        self.request.assert_called_once()
-
-    def test_access_error_triggers_auth_attempt(self):
-        self.conn._auth.can_refresh_session.return_value = False
-        value_error = ValueError('no json')
-        mock_response = mock.Mock()
-        mock_response.json.side_effect = value_error
-        mock_response.status_code = http_client.FORBIDDEN
-        # This doesn't test/wire all way back through auth -> main
-        # and ultimately we want to make sure we get an error all
-        # the way back.
-        self.conn._auth.authenticate.side_effect = \
-            exceptions.AccessError('GET', '/', mock_response)
-        self.request.return_value.status_code = http_client.FORBIDDEN
-        self.request.return_value.json.side_effect = value_error
-
-        with self.assertRaisesRegex(exceptions.AccessError,
-                                    'unknown error') as cm:
-            self.conn._op('GET', 'http://foo.bar')
-        exc = cm.exception
-        self.assertEqual(http_client.FORBIDDEN, exc.status_code)
-        self.conn._auth.authenticate.assert_called_once()
-
-    def test_access_error_without_auth(self):
-        self.conn._auth = None
-
-        self.request.return_value.status_code = http_client.FORBIDDEN
-        self.request.return_value.json.side_effect = ValueError('no json')
-
-        with self.assertRaisesRegex(exceptions.AccessError,
-                                    'unknown error') as cm:
-            self.conn._op('GET', 'http://foo.bar')
-        exc = cm.exception
-        self.assertEqual(http_client.FORBIDDEN, exc.status_code)
-
-    @mock.patch.object(connector.LOG, 'debug', autospec=True)
-    def test_access_error_service_session_reauth(self, mock_log):
         self.conn._auth.can_refresh_session.return_value = False
 
         self.request.return_value.status_code = http_client.FORBIDDEN
-        mock_response = mock.Mock()
-        mock_response.json.side_effect = ValueError('no json')
-        mock_response.status_code = http_client.FORBIDDEN
-        self.conn._auth.authenticate.side_effect = \
-            exceptions.AccessError('POST', 'fake/path', mock_response)
         self.request.return_value.json.side_effect = ValueError('no json')
 
         with self.assertRaisesRegex(exceptions.AccessError,
                                     'unknown error') as cm:
-            self.conn._op('GET', 'http://redfish/v1/SessionService')
+            self.conn._op('GET', 'http://foo.bar')
         exc = cm.exception
         self.assertEqual(http_client.FORBIDDEN, exc.status_code)
-        self.conn._auth.authenticate.assert_called_once()
-
-    @mock.patch.object(connector.LOG, 'debug', autospec=True)
-    def test_access_error_service_session_no_auth(self, mock_log):
-        self.conn._auth = None
-
-        self.request.return_value.status_code = http_client.FORBIDDEN
-        self.request.return_value.json.side_effect = ValueError('no json')
-
-        with self.assertRaisesRegex(exceptions.AccessError,
-                                    'unknown error') as cm:
-            self.conn._op('GET', 'http://redfish/v1/SessionService')
-        exc = cm.exception
-        mock_log.assert_called_with(
-            'HTTP GET of SessionService failed %s, '
-            'this is expected prior to authentication', 'HTTP GET '
-            'http://redfish/v1/SessionService returned code '
-            'HTTPStatus.FORBIDDEN. unknown error')
-        self.assertEqual(http_client.FORBIDDEN, exc.status_code)
 
     def test_blocking_no_location_header(self):
         self.request.return_value.status_code = http_client.ACCEPTED
